Enum pallet_indices::pallet::Call [−][src]
pub enum Call<T: Config> {
claim {
index: T::AccountIndex,
},
transfer {
new: T::AccountId,
index: T::AccountIndex,
},
free {
index: T::AccountIndex,
},
force_transfer {
new: T::AccountId,
index: T::AccountIndex,
freeze: bool,
},
freeze {
index: T::AccountIndex,
},
// some variants omitted
}Expand description
Contains one variant per dispatchable that can be called by an extrinsic.
Variants
Assign an previously unassigned index.
Payment: Deposit is reserved from the sender account.
The dispatch origin for this call must be Signed.
index: the index to be claimed. This must not be in use.
Emits IndexAssigned if successful.
O(1).- One storage mutation (codec
O(1)). - One reserve operation.
- One event.
- DB Weight: 1 Read/Write (Accounts)
Fields of claim
index: T::AccountIndexAssign an index already owned by the sender to another account. The balance reservation is effectively transferred to the new account.
The dispatch origin for this call must be Signed.
index: the index to be re-assigned. This must be owned by the sender.new: the new owner of the index. This function is a no-op if it is equal to sender.
Emits IndexAssigned if successful.
O(1).- One storage mutation (codec
O(1)). - One transfer operation.
- One event.
- DB Weight:
- Reads: Indices Accounts, System Account (recipient)
- Writes: Indices Accounts, System Account (recipient)
Fields of transfer
new: T::AccountIdindex: T::AccountIndexFree up an index owned by the sender.
Payment: Any previous deposit placed for the index is unreserved in the sender account.
The dispatch origin for this call must be Signed and the sender must own the index.
index: the index to be freed. This must be owned by the sender.
Emits IndexFreed if successful.
O(1).- One storage mutation (codec
O(1)). - One reserve operation.
- One event.
- DB Weight: 1 Read/Write (Accounts)
Fields of free
index: T::AccountIndexForce an index to an account. This doesn’t require a deposit. If the index is already held, then any deposit is reimbursed to its current owner.
The dispatch origin for this call must be Root.
index: the index to be (re-)assigned.new: the new owner of the index. This function is a no-op if it is equal to sender.freeze: if set totrue, will freeze the index so it cannot be transferred.
Emits IndexAssigned if successful.
O(1).- One storage mutation (codec
O(1)). - Up to one reserve operation.
- One event.
- DB Weight:
- Reads: Indices Accounts, System Account (original owner)
- Writes: Indices Accounts, System Account (original owner)
Fields of force_transfer
Freeze an index so it will always point to the sender account. This consumes the deposit.
The dispatch origin for this call must be Signed and the signing account must have a
non-frozen account index.
index: the index to be frozen in place.
Emits IndexFrozen if successful.
O(1).- One storage mutation (codec
O(1)). - Up to one slash operation.
- One event.
- DB Weight: 1 Read/Write (Accounts)
Fields of freeze
index: T::AccountIndexImplementations
Create a call with the variant claim.
Create a call with the variant transfer.
Create a call with the variant free.
pub fn new_call_variant_force_transfer(
new: T::AccountId,
index: T::AccountIndex,
freeze: bool
) -> Self
pub fn new_call_variant_force_transfer(
new: T::AccountId,
index: T::AccountIndex,
freeze: bool
) -> Self
Create a call with the variant force_transfer.
Create a call with the variant freeze.